==> scummvm_0.13.0-2.tar.gz: scummvm-0.13.0/common/queue.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-0-13-0/common/queue.h $
 * $Id: queue.h 35651 2009-01-01 17:05:05Z fingolfin $
 */

#ifndef COMMON_QUEUE_H
#define COMMON_QUEUE_H

#include "common/scummsys.h"
#include "common/list.h"

namespace Common {

/**
 * Variable size Queue class, implemented using our List class.
 */
template<class T>
class Queue {
public:
	typedef T value_type;

public:
	Queue<T>() : _impl() {}
	Queue<T>(const Queue<T> &queue) : _impl(queue._impl) {}

	Queue<T> &operator=(const Queue<T> &queue) {
		_impl = queue._impl;
		return *this;
	}

	bool empty() const {
		return _impl.empty();
	}

	void clear() {
		_impl.clear();
	}

	void push(const T &x) {
		_impl.push_back(x);
	}

	T &front() {
		return *_impl.begin();
	}

	const T &front() const {
		return *_impl.begin();
	}

	T &back() {
		return *_impl.reverse_begin();
	}

	const T &back() const {
		return *_impl.reverse_begin();
	}

	T pop() {
		T tmp = front();
		_impl.pop_front();
		return tmp;
	}

	int size() const {
		return _impl.size();
	}

private:
	List<T>	_impl;
};

} // End of namespace Common

#endif

==> scummvm_1.0.0~rc1-1.orig.tar.gz: scummvm-1.0.0rc1/common/queue.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-0-0rc1/common/queue.h $
 * $Id: queue.h 40154 2009-04-27 11:11:42Z fingolfin $
 */

#ifndef COMMON_QUEUE_H
#define COMMON_QUEUE_H

#include "common/scummsys.h"
#include "common/list.h"

namespace Common {

/**
 * Variable size Queue class, implemented using our List class.
 */
template<class T>
class Queue {
//public:
//	typedef T value_type;

public:
	Queue<T>() : _impl() {}
	Queue<T>(const Queue<T> &queue) : _impl(queue._impl) {}

	bool empty() const {
		return _impl.empty();
	}

	void clear() {
		_impl.clear();
	}

	void push(const T &x) {
		_impl.push_back(x);
	}

	T &front() {
		return _impl.front();
	}

	const T &front() const {
		return _impl.front();
	}

	T &back() {
		return _impl.back();
	}

	const T &back() const {
		return _impl.back();
	}

	T pop() {
		T tmp = front();
		_impl.pop_front();
		return tmp;
	}

	int size() const {
		return _impl.size();
	}

private:
	List<T>	_impl;
};

} // End of namespace Common

#endif
